@@ -42,6 +42,7 @@ class ScrapeMapper:
         self.Cascade = CascadeItem({})
         self.Forums = ForumItem({})
         self.skip_data = SkipData(args['Ignore']['skip_hosts'])
+        self.only_data = SkipData(args['Ignore']['only_hosts'])
 
         self.unsupported_file = args["Files"]["unsupported_urls_file"]
         self.unsupported_output = args['Runtime']['output_unsupported_urls']
@@ -88,7 +89,7 @@ class ScrapeMapper:
         self.socialmediagirls_semaphore = asyncio.Semaphore(1)
         self.xbunker_semaphore = asyncio.Semaphore(1)
 
-        self.mapping = {"anonfiles": self.Anonfiles, "bayfiles": self.Anonfiles,"xbunkr": self.XBunkr,
+        self.mapping = {"anonfiles": self.Anonfiles, "bayfiles": self.Anonfiles, "xbunkr": self.XBunkr,
                         "bunkr": self.Bunkr, "cyberdrop": self.Cyberdrop, "cyberfile": self.CyberFile,
                         "erome": self.Erome, "fapello": self.Fapello, "gfycat": self.Gfycat, "gofile": self.GoFile,
                         "hgamecg": self.HGameCG, "imgbox": self.ImgBox, "pixeldrain": self.PixelDrain,
@@ -342,7 +343,12 @@ class ScrapeMapper:
             return
         for key, value in self.mapping.items():
             if key in url_to_map.host:
-                if any(site in key for site in self.skip_data.sites):
+                if self.only_data.sites:
+                    if any(site in key for site in self.only_data.sites):
+                        await value(url=url_to_map, title=title)
+                    else:
+                        await log(f"[yellow]Skipping: {str(url_to_map)}[/yellow]", quiet=self.quiet)
+                elif any(site in key for site in self.skip_data.sites):
                     await log(f"[yellow]Skipping: {str(url_to_map)}[/yellow]", quiet=self.quiet)
                 else:
                     await value(url=url_to_map, title=title)
